#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
	module API
		module Remittance
			class RetrieveRemittance < MasterCard::Core::Model::BaseObject
				include MasterCard::Core::Model
				#

				@__store = {
					'456148d2-8471-47fc-a782-7ba53c1b796e' => OperationConfig.new("/send/v1/partners/{id}/remittances/{remittance-id}", "read", [], []),
					'22d72517-b03b-4dcd-bbe0-92bfb639e790' => OperationConfig.new("/send/v1/partners/{id}/remittances", "query", [], ["remittance-reference"]),
					
				}

				protected

				def self.getOperationConfig(uuid)
					if @__store.key?(uuid)
						return @__store[uuid]
					end
					raise NotImplementedError.new("Invalid operationUUID supplied:"+ uuid)
				end

				def self.getOperationMetadata()
					return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext())
				end

				public






				def self.readByID(id, criteria = nil)
					#
					#Returns objects of type RetrieveRemittance by id and optional criteria
					#@param [String] id
					#@param [Dict] criteria
					#@return [RetrieveRemittance] object representing the response
					#@raise [APIException] an exception from the response status

					mapObj = RetrieveRemittance.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !criteria.nil?
						if criteria.instance_of? RequestMap
						  mapObj.setAll(criteria.getObject())
						else
						  mapObj.setAll(criteria)
						end
					end

					return self.execute("456148d2-8471-47fc-a782-7ba53c1b796e",RetrieveRemittance.new(mapObj))
				end








				def self.readByReference(criteria)
					#
					#Query objects of type RetrieveRemittance by id and optional criteria
					#@param [Dict] criteria
					#@return [RetrieveRemittance] object representing the response.
					#@raise [APIException] an exception from the response status
					#

					return self.execute("22d72517-b03b-4dcd-bbe0-92bfb639e790",RetrieveRemittance.new(criteria))
				end


			end
		end
	end
end







